==> open-cluster-management-apps-model-5.12.4-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/helmrelease/v1/AltSourceBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class AltSourceBuilder extends io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.AltSourceFluentImpl<io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.AltSourceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.AltSource,io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.AltSourceBuilder>{
  public AltSourceBuilder() {
    this(false);
  }
  public AltSourceBuilder(java.lang.Boolean validationEnabled) {
    this(new AltSource(), validationEnabled);
  }
  public AltSourceBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.AltSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public AltSourceBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.AltSourceFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new AltSource(), validationEnabled);
  }
  public AltSourceBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.AltSourceFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.AltSource instance) {
    this(fluent, instance, false);
  }
  public AltSourceBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.AltSourceFluent<?> fluent,io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.AltSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConfigMapRef(instance.getConfigMapRef()); 
    fluent.withGit(instance.getGit()); 
    fluent.withGithub(instance.getGithub()); 
    fluent.withHelmRepo(instance.getHelmRepo()); 
    fluent.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    fluent.withSecretRef(instance.getSecretRef()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public AltSourceBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.AltSource instance) {
    this(instance,false);
  }
  public AltSourceBuilder(io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.AltSource instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withConfigMapRef(instance.getConfigMapRef()); 
    this.withGit(instance.getGit()); 
    this.withGithub(instance.getGithub()); 
    this.withHelmRepo(instance.getHelmRepo()); 
    this.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    this.withSecretRef(instance.getSecretRef()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.AltSourceFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1.AltSource build() {
    AltSource buildable = new AltSource(fluent.getConfigMapRef(),fluent.getGit(),fluent.getGithub(),fluent.getHelmRepo(),fluent.getInsecureSkipVerify(),fluent.getSecretRef(),fluent.getType());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AltSourceBuilder that = (AltSourceBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> open-cluster-management-apps-model-6.1.1-sources.jar: io/fabric8/openclustermanagement/api/model/multicloudoperatorssubscription/apps/helmrelease/v1/AltSourceBuilder.java <==
package io.fabric8.openclustermanagement.api.model.multicloudoperatorssubscription.apps.helmrelease.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class AltSourceBuilder extends AltSourceFluentImpl<AltSourceBuilder> implements VisitableBuilder<AltSource,AltSourceBuilder>{
  public AltSourceBuilder() {
    this(false);
  }
  public AltSourceBuilder(Boolean validationEnabled) {
    this(new AltSource(), validationEnabled);
  }
  public AltSourceBuilder(AltSourceFluent<?> fluent) {
    this(fluent, false);
  }
  public AltSourceBuilder(AltSourceFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new AltSource(), validationEnabled);
  }
  public AltSourceBuilder(AltSourceFluent<?> fluent,AltSource instance) {
    this(fluent, instance, false);
  }
  public AltSourceBuilder(AltSourceFluent<?> fluent,AltSource instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withConfigMapRef(instance.getConfigMapRef()); 
    fluent.withGit(instance.getGit()); 
    fluent.withGithub(instance.getGithub()); 
    fluent.withHelmRepo(instance.getHelmRepo()); 
    fluent.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    fluent.withSecretRef(instance.getSecretRef()); 
    fluent.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  public AltSourceBuilder(AltSource instance) {
    this(instance,false);
  }
  public AltSourceBuilder(AltSource instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withConfigMapRef(instance.getConfigMapRef()); 
    this.withGit(instance.getGit()); 
    this.withGithub(instance.getGithub()); 
    this.withHelmRepo(instance.getHelmRepo()); 
    this.withInsecureSkipVerify(instance.getInsecureSkipVerify()); 
    this.withSecretRef(instance.getSecretRef()); 
    this.withType(instance.getType()); 
    this.validationEnabled = validationEnabled; 
  }
  AltSourceFluent<?> fluent;
  Boolean validationEnabled;
  public AltSource build() {
    AltSource buildable = new AltSource(fluent.getConfigMapRef(),fluent.getGit(),fluent.getGithub(),fluent.getHelmRepo(),fluent.getInsecureSkipVerify(),fluent.getSecretRef(),fluent.getType());
    return buildable;
  }
  
}
